<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output method="html"/>

    <!-- Modules -->
    <xsl:include href="../../modules/main/main.xsl"/>
    <xsl:include href="../../modules/settings/settings.xsl"/>
    <xsl:include href="../../modules/chat/chat.xsl"/>
    <xsl:include href="../../modules/calls/calls.xsl"/>
    <xsl:include href="../../modules/roster/roster.xsl"/>
    <xsl:include href="../../modules/function_keys/function_keys.xsl"/>
    <xsl:include href="../../modules/phonebook/phonebook.xsl"/>
    <xsl:include href="../../modules/history/history.xsl"/>
    <xsl:include href="../../modules/voicemail/voicemail.xsl"/>
    <xsl:include href="../../modules/web_app/web_app.xsl"/>
    <xsl:include href="../../modules/cdrview/cdrview.xsl"/>
    <xsl:include href="../../modules/screen_sharing/screen_sharing.xsl"/>
    <xsl:include href="../../modules/webrtc_zero_distance/webrtc_zero_distance.xsl"/>
    <xsl:include href="../../modules/calendar/calendar.xsl"/>
    <xsl:include href="../../modules/video_sharing/video_sharing.xsl"/>

    <xsl:template match="/">
        <html>
            <xsl:attribute name="lang"><xsl:value-of select="/root/@lang" /></xsl:attribute>
            <xsl:attribute name="xml:lang"><xsl:value-of select="/root/@lang" /></xsl:attribute>
            <head>
                <meta name="language">
                     <xsl:attribute name="content">
                             <xsl:value-of select="/root/@full_lang" />
                    </xsl:attribute>
                </meta>
                <meta http-equiv="Content-Language">
                    <xsl:attribute name="content"><xsl:value-of select="/root/@lang" /></xsl:attribute>
                </meta>

                <meta http-equiv="content-type" content="text/html; charset=utf-8"/>
                <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1"/>

                <link rel="manifest" href="../manifest.json" />

                <link rel="shortcut icon" type="image/x-icon">
                	    <xsl:attribute name="href">../<xsl:value-of select="/root/@favicon" />?version-<xsl:value-of select="/root/@version" /></xsl:attribute>
                </link>

                <title>
                    <xsl:value-of select="/root/@collaboration"/>
                </title>


                <link rel="chrome-webstore-item" href="https://chrome.google.com/webstore/detail/lobgohpoobpijgfegnlhdnppegdbomkn"></link>

                <link rel="stylesheet" type="text/css">
                    <xsl:attribute name="href">dist/collaboration.css?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </link>


                <xsl:if test="/root/@browser_firefox">
                    <!-- ff css -->
                    <link rel="stylesheet" type="text/css">
                    	    <xsl:attribute name="href">data/css/firefox.css?version-<xsl:value-of select="/root/@version" /></xsl:attribute>
                    </link>
                </xsl:if>

                <xsl:if test="/root/@ipad > 0">
                    <!-- webkit css -->
                    <link rel="stylesheet" type="text/css">
                    	    <xsl:attribute name="href">data/css/ipad.css?version-<xsl:value-of select="/root/@version" /></xsl:attribute>
                    </link>
                </xsl:if>

                <xsl:if test="/root/@galaxy > 0">
                    <link rel="stylesheet" type="text/css">
                        <xsl:attribute name="href">data/css/galaxy.css?version-<xsl:value-of select="/root/@version" /></xsl:attribute>
                    </link>
                </xsl:if>

                <xsl:if test="/root/@custom_css != ''">
                    <link href="" rel="stylesheet" type="text/css">
                        <xsl:attribute name="href">../<xsl:value-of select="/root/@custom_css" />?version-<xsl:value-of select="/root/@version" /></xsl:attribute>
                    </link>
                </xsl:if>


                <script type="text/javascript">
                    window.env = {
                        integration: '<xsl:value-of select="/root/@integrationHost"/>'
                    }
                    function log() {
                        console.log.apply(console, arguments);
                    }
                    var video_conference_host = '<xsl:value-of select="/root/modules/module_video_conference/host" />';
                    var application_lang = '<xsl:value-of select="/root/@lang" />';

                    var serverTimeDiff = parseInt('<xsl:value-of select="/root/@server_time" />')*1000 - new Date().getTime();
                        getServerTime = function(){
                            if (Date.now)
                                return Date.now() + serverTimeDiff;
                            else
                                return new Date().getTime() + serverTimeDiff;
                        };


                        if (window.navigator.userAgent.indexOf("MSIE ") != -1|| !!navigator.userAgent.match(/Trident.*rv\:11\./)) {
                            var head = document.getElementsByTagName('head')[0];
                            var script = document.createElement('script');
                            script.setAttribute('src', '../js/bluebird.min.js');
                            script.setAttribute('type', 'text/javascript');
                            script.setAttribute('async', 'false');
                            head.appendChild(script);
                        }
                </script>

                <!-- <script type="text/javascript" src="/collaboration/libs/js/sip-0.7.0.min.js"></script> -->

                <script type="text/javascript">
                    <xsl:attribute name="src">data/js/langs/cti_lang<xsl:value-of select="/root/@lang" />.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

                <script type="text/javascript">
                    <xsl:attribute name="src">dist/common.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

                <script type="text/javascript">
                    <xsl:attribute name="src">dist/collaboration.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

                <script type="text/javascript">
                    <xsl:attribute name="src">../js/firebase/firebase-app-messaging.packed.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

                <script type="text/javascript">
                    <xsl:attribute name="src">data/js/index.js?version=<xsl:value-of select="/root/@version" /></xsl:attribute>
                </script>

            </head>

            <body class="main">
                <div id="cti_loaded_modules" class="hidden_block">
                    <xsl:value-of select="/root/js_modules_names" />
                </div>

                <noscript><div style="width: 100%; text-align: center; color: #FFF">Your browser does not support JavaScript or JavaScript turned off</div></noscript>

                <div valign="top">
	                <div id="cti_main_tabs">
	                	<div id="top_Header_main">
	                		<div id="top_Header">
                                <div id="Logo">
                                    <xsl:choose>
                                        <xsl:when test="/root/@isTopLinkEnabled = 1">
                                            <a href="" target="_blank">
                                                <xsl:attribute name="href"><xsl:value-of select="/root/@site" /></xsl:attribute>
                                                <img src="">
                                                    <xsl:attribute name="src">../<xsl:value-of select="/root/@logo" /></xsl:attribute>
                                                </img>
                                            </a>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <img src="">
                                                <xsl:attribute name="src">../<xsl:value-of select="/root/@logo" /></xsl:attribute>
                                            </img>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </div>
			                    <div class="searchbox">
			                        <xsl:apply-templates select="/root/modules/module_roster/searchbox"/>
			                        <xsl:apply-templates select="/root/modules/module_roster/click2call"/>
                                    <div id="select-device" class="inline" tabindex="-1"></div>
                                    <div id="click2call_noconnection" class="inline">
                                        <i class="fa fa-ban"></i>
                                    </div>
                                    <xsl:if test="((/root/modules/module_sms/@enabled = '1') or (/root/modules/module_fax/@enabled = '1') or (/root/modules/module_postit/button_icon/@enabled = '1'))">
                                        <button id="module_roster_more_actions_btn"></button>
                                    </xsl:if>
                                    <xsl:if test="/root/modules/module_video_conference/@enabled = '1'">
                                        <button id="module_video_conference_list_btn" class="roster-video-conference-btn-icon">
                                            <xsl:attribute name="title"><xsl:value-of select="/root/trans_texts/conference.create_video_conference"/></xsl:attribute>
                                        </button>
                                    </xsl:if>
			                    </div>

			                    <ul>
			                        <xsl:if test="/root/modules/module_roster/@enabled = '1'">
	        							<xsl:apply-templates select="/root/modules/module_roster/tab"/>
	        							<xsl:apply-templates select="/root/modules/module_function_keys/tab"/>
			                            <xsl:apply-templates select="/root/modules/module_chat/tab"/>
			                        </xsl:if>

			                        <xsl:if test="/root/modules/module_phonebook">
			                            <xsl:apply-templates select="/root/modules/module_phonebook/tab"/>
			                        </xsl:if>
			                        <xsl:if test="/root/modules/module_history/@enabled = '1'">
			                             <xsl:apply-templates select="/root/modules/module_history/tab"/>
			                        </xsl:if>
			                        <xsl:if test="/root/modules/module_voicemail/@enabled = '1'">
			                             <xsl:apply-templates select="/root/modules/module_voicemail/tab"/>
			                        </xsl:if>
			                        <xsl:if test="/root/modules/module_web_app/@enabled = '1'">
			                             <xsl:apply-templates select="/root/modules/module_web_app/tab"/>
			                        </xsl:if>
                                    <xsl:if test="/root/modules/module_settings">
                                        <xsl:apply-templates select="/root/modules/module_settings/tab"/>
                                    </xsl:if>
			                        <li id="cti_main_tabs_other_tab">
							            <a href="#cti_main_tabs_other" class="cti_main_tabs_other_tab_a">
							            	<xsl:attribute name="title"><xsl:value-of select="/root/trans_texts/link.Other"/></xsl:attribute>
							            	<i class="fa fa-sort-desc"></i>
							           	</a>
							        </li>
			                    </ul>
			                    <div class="avatar">
		                            <a href='#' id="userpic" class="avatar_exists">
		                                <xsl:if test="/root/modules/module_main/avatar">
		                                    <img id="module_main_avatar_image">
		                                        <xsl:attribute name="src"><xsl:value-of select="/root/modules/module_main/avatar"/></xsl:attribute>
		                                    </img>
		                                </xsl:if>
		                            </a>
		                            <div class="status-box">
				                    	<xsl:apply-templates select="/root/modules/module_roster/my-icon"/>
				                    </div>
		                        </div>

		                        <div class="nickname_div">
			                        <table>
			                        	<tr>
			                        		<td>
			                        			<span id="myNickname" class="nickName"><xsl:value-of select="/root/modules/module_main/texts/user_name"/></span>
			                        			<span id="myHeaderStatus"></span>
			                        			<span id="myHeaderLocation"></span>
			                        		</td>
			                        	</tr>

			                        </table>
		                        </div>
                                <xsl:if test="/root/modules/module_main/custom_logo">
                                    <div class="custom_logo_wrapper">
                                        <img class="custom_logo">
                                            <xsl:attribute name="src"><xsl:value-of select="/root/modules/module_main/custom_logo"/></xsl:attribute>
                                            <xsl:attribute name="title"><xsl:value-of select="/root/trans_texts/strings.providedBy" /></xsl:attribute>
                                        </img>
                                    </div>
                                </xsl:if>
		                        <div style="clear: both;"></div>
		                	</div>
		                <div id="cti_main_tabs_map" style="display:none;"></div>
		                <div id="cti_main_tabs_other" class="cti_main_tabs_other block_shadow">
		                	<ul>
			                	<xsl:if test="/root/modules/module_cdrview/@enabled = '1'">
		                            <xsl:if test="/root/@ipad != 1">
		                                <xsl:apply-templates select="/root/modules/module_cdrview/tab"/>
		                            </xsl:if>
			                    </xsl:if>

                                <xsl:if test="/root/modules/module_roster/@enabled = '1'">
                                    <li>
                                        <a href="javascript:void(0)" class="link-map">
                                            <i class="fa fa-map-marker fa-fw"></i>
                                            <xsl:apply-templates select="/root/trans_texts/roster.MapView"/>
                                        </a>
                                    </li>
                                </xsl:if>

                                <li><hr></hr></li>

			                    <xsl:if test="/root/modules/module_roster/@enabled = '1'">
                                    <xsl:if test="/root/modules/module_roster/@see_colleague = '1'">
                                        <li>
                                            <a href='javascript:void(0)' class="link-edit-colleagues">
                                                <i class="fa fa-male fa-fw"></i>&#160;<xsl:value-of select="/root/trans_texts/roster.menu.EditColleagues" />
                                            </a>
                                        </li>
                                    </xsl:if>
                                    <li>
                                        <a href='javascript:void(0)' class="link-offline-users">
                                            <i class="fa fa-empty fa-fw"></i>
                                            <xsl:value-of select="/root/trans_texts/Options.HideOfflineUsers" />
                                        </a>
                                    </li>

                                    <li><hr></hr></li>

                                    <li>
                                        <a href='javascript:void(0)' class="link-show-post-it">
                                            <i class="fa fa-empty fa-fw"></i>
                                            <xsl:value-of select="/root/trans_texts/roster.ConfigBtn.ShowPostIt" />
                                        </a>
                                    </li>
				                    <li>
                                        <a href='javascript:void(0)' class="link-history-post-it">
                                            <i class="fa fa-empty fa-fw"></i>
                                            <xsl:value-of select="/root/trans_texts/roster.ConfigBtn.HistoryPostIt" />
                                        </a>
                                    </li>

                                    <li><hr></hr></li>
			                    </xsl:if>
			                    <xsl:if test="/root/@userKind='admin'">
			                    	<li>
			                    		<a id="managePBX_icon" href="../?wms" target="_blank">
			                    			<i class="fa fa-wrench fa-fw"></i>&#160;<xsl:value-of select="/root/trans_texts/label.managePBX" />
	                                    </a>
			                    	</li>
                                </xsl:if>

                                <xsl:if test="/root/@screen_sharing = 1">
                                    <xsl:apply-templates select="/root/modules/module_screen_sharing/room_manager_button"/>
                                </xsl:if>
                                <xsl:if test="/root/modules/module_attendant_console/@enabled = '1'">
                                    <li>
                                        <a id="attendant_console_btn" href="javascript:void(0)">
                                            <i class="fa fa-tty fa-fw"></i>&#160;<xsl:value-of select="/root/trans_texts/AttendantConsole.open" />
                                        </a>
                                    </li>
                                </xsl:if>
                                <xsl:if test="/root/modules/module_fax">
                                    <xsl:if test="/root/modules/module_fax/@enabled = '1'">
                                        <li>
                                            <a id="fax_queue_icon" href="javascript:void(0)">
                                                <i class="fa fa-fax fa-fw"></i>&#160;<xsl:value-of select="/root/trans_texts/label.OutgoingFaxes" />
                                            </a>
                                        </li>
                                    </xsl:if>
                                </xsl:if>
                                <xsl:if test="((/root/modules/module_fax and /root/modules/module_fax/@enabled = '1') or /root/@userKind='admin' or /root/@screen_sharing = 1 or /root/modules/module_attendant_console/@enabled = '1')">
                                	<li><hr></hr></li>
                                </xsl:if>
                                <li>
                                    <a target="_top" id="logout_btn" onclick="return false">
                                        <i class="fa fa-sign-out fa-fw"></i>&#160;<xsl:value-of select="/root/trans_texts/buttons.Logout"/>
                                    </a>
                                </li>
                                <xsl:if test="/root/@isHelpLinkEnabled = 1">
                                    <li>
                                        <a target="_blank" href="" >
                                            <xsl:attribute name="href"><xsl:value-of select="/root/@helpLink" /></xsl:attribute>
                                            <i class="fa fa-question-circle-o fa-fw"></i>&#160;<xsl:value-of select="/root/trans_texts/main.help"/>
                                        </a>
                                    </li>
                                </xsl:if>
                                <li>
                                    <a target="_blank" href="">
                                        <xsl:attribute name="href"><xsl:value-of select="/root/@licenseLink" /></xsl:attribute>
                                        <i class="fa fa-user fa-fw"></i>&#160;<xsl:value-of select="/root/trans_texts/main.license"/>&#160;
                                        <xsl:choose>
                                            <xsl:when test="/root/@licenseType = 'basic'">
                                                <xsl:value-of select="/root/trans_texts/license.type.basic" />
                                            </xsl:when>
                                            <xsl:when test="/root/@licenseType = 'essential'">
                                                <xsl:value-of select="/root/trans_texts/license.type.essential" />
                                            </xsl:when>
                                            <xsl:when test="/root/@licenseType = 'business'">
                                                <xsl:value-of select="/root/trans_texts/license.type.business" />
                                            </xsl:when>
                                            <xsl:when test="/root/@licenseType = 'premium'">
                                                <xsl:value-of select="/root/trans_texts/license.type.premium" />
                                            </xsl:when>
                                            <xsl:when test="/root/@licenseType = 'wizyconf'">
                                                <xsl:value-of select="/root/trans_texts/license.type.wizyconf" />
                                            </xsl:when>
                                        </xsl:choose>
                                    </a>
                                </li>
                                <li>
                                	<a target="_blank" href="" >
                                	   <xsl:attribute name="href"><xsl:value-of select="/root/@legal" /></xsl:attribute>
                                       <i class="fa fa-info-circle fa-fw"></i>&#160;<xsl:value-of select="/root/trans_texts/main.About"/>&#160;<xsl:value-of select="/root/@version" />
                                	 </a>
                                </li>
		                    </ul>
		                    </div>
		                </div>
		                <div id="content_center" class="block_shadow">
		                    <xsl:if test="/root/modules/module_roster/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_roster"/>
		                        <xsl:apply-templates select="/root/modules/module_function_keys"/>
		                        <xsl:apply-templates select="/root/modules/module_chat/tab_content"/>
		                    </xsl:if>

		                    <xsl:if test="/root/modules/module_phonebook">
		                        <xsl:apply-templates select="/root/modules/module_phonebook/tab_content"/>
		                    </xsl:if>
		                    <xsl:if test="/root/modules/module_history/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_history/tab_content"/>
		                    </xsl:if>
							<xsl:if test="/root/modules/module_voicemail/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_voicemail/tab_content"/>
		                    </xsl:if>
		                    <xsl:if test="/root/modules/module_web_app/@enabled = '1'">
		                        <xsl:apply-templates select="/root/modules/module_web_app/tab_content"/>
		                    </xsl:if>
		                    <xsl:if test="/root/modules/module_cdrview/@enabled = '1'">
		                        <xsl:if test="/root/@ipad != 1">
		                            <xsl:apply-templates select="/root/modules/module_cdrview/tab_content"/>
		                        </xsl:if>
		                    </xsl:if>
		                    <xsl:if test="/root/modules/module_settings">
		                        <xsl:apply-templates select="/root/modules/module_settings"/>
		                    </xsl:if>
	                    </div>
	                </div>
	            </div>

                <div id="main_popup_dialogs_div" class="hidden_block"></div>

                <div id="user_data" class="hidden_block">
                    <xsl:value-of select="/root/user_data" />
                </div>

                <div id="licensies" class="hidden_block">
                    <xsl:value-of select="/root/licensies" />
                </div>

                <div id="user_features" class="hidden_block">
                    <xsl:value-of select="/root/user_features" />
                </div>

                <div id="user_acl" class="hidden_block">
                    <xsl:value-of select="/root/user_acl" />
                </div>

                <div id="pbx_configs" class="hidden_block">
                    <xsl:value-of select="/root/pbx_configs" />
                </div>

                <xsl:if test="/root/modules/module_main">
                   <xsl:apply-templates select="/root/modules/module_main"/>
                </xsl:if>

                <xsl:if test="/root/modules/module_chat">
                   <xsl:apply-templates select="/root/modules/module_chat"/>
                </xsl:if>

                <xsl:if test="/root/modules/module_calls">
                   <xsl:apply-templates select="/root/modules/module_calls"/>
                </xsl:if>

                <xsl:if test="/root/modules/module_roster">
                   <xsl:apply-templates select="/root/modules/module_roster/context-menu"/>
                </xsl:if>
				<xsl:if test="/root/modules/module_function_keys">
                   <xsl:apply-templates select="/root/modules/module_function_keys/context-menu"/>
                </xsl:if>
                <xsl:if test="/root/modules/module_chat">
                   <xsl:apply-templates select="/root/modules/module_chat/context-menu"/>
                </xsl:if>
                <xsl:if test="/root/modules/module_screen_sharing">
                    <xsl:apply-templates select="/root/modules/module_screen_sharing"/>
                </xsl:if>
                <xsl:if test="/root/modules/module_webrtc_zero_distance">
                    <xsl:apply-templates select="/root/modules/module_webrtc_zero_distance"/>
                </xsl:if>
                <xsl:if test="/root/modules/module_video_sharing">
                    <xsl:apply-templates select="/root/modules/module_video_sharing"/>
                </xsl:if>
				<xsl:if test="/root/modules/module_calendar">
                    <xsl:apply-templates select="/root/modules/module_calendar"/>
                </xsl:if>
                <xsl:if test="/root/@sslCertificateExpireDays >= 0">
                    <div id="ssl_certificate_expire_days" class="hidden_block">
                        <xsl:value-of select="/root/@sslCertificateExpireDays" />
                    </div>
                </xsl:if>
                <div id="preload_div" class="hidden_block">
                    <div class='img_48' rel="error_48"></div>
                </div>
            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>
