(function universalModuleDefinition(root, factory) {
    if (typeof module === 'object' && module.exports) {
        // CommonJS
        module.exports = factory(require('jquery'), require('WMS'));
    } else if (typeof define === 'function' && define.amd) {
        // AMD
        define(['jquery', 'WMS'], factory);
    } else {
        // Browser
        root.RemoteSyslogSettings = factory(root.jQuery, root.WMS);
    }
}(this, function($, WMS) {
    'use strict';

    function RemoteSyslogSettings(data, remoteSyslogOptions) {
        if (typeof data === 'object') {
            this._settings = data;
        }

        this._remoteSyslogOptions = remoteSyslogOptions;
    }

    $.extend(RemoteSyslogSettings.prototype, {
        _htmlContainer: $('.main-content'),

        load: function() {
            this._render();
            this._initForm();
        },

        _render: function() {
            var content = $.tmpl(
                'settings.remote_syslog_configuration',
                {
                    'title': WMS._t('menu.remote_syslog'),
                    'txt': {
                        'enabled': WMS._t('remote_syslog.label.enabled'),
                        'filter': WMS._t('remote_syslog.label.filter'),
                        'transport': WMS._t('remote_syslog.label.transport'),
                        'format': WMS._t('remote_syslog.label.format'),
                        'destination': WMS._t('remote_syslog.label.destination'),
                        'save': WMS._t('buttons.Save'),
                        'host': WMS._t('strings.Host')
                    },
                    'options': this._remoteSyslogOptions,
                    'settings': this._settings
                }
            );

            this._htmlContainer.append(content);
        },

        _initForm: function() {
            var form = this._htmlContainer.find('.remote_syslog_settings_form');

            form.checkForm({
                rules: [
                    'required,remote_syslog_settings_filter,' + WMS._t('rules.CannotBeEmpty'),
                    'required,remote_syslog_settings_host,' + WMS._t('rules.CannotBeEmpty')
                ]
            });

            form.apiForm({
                load: 'api/v1/PBX/settings/RemoteSyslog/',
                submit: 'api/v1/PBX/settings/RemoteSyslog/',

                error: function(response) {
                    setError('error', response.reason, 5000);
                },

                beforeSubmit: function() {
                    if (!form.checkForm('validate')) {
                        return false;
                    }

                    this._lock();

                    return true;
                }.bind(this),

                afterSubmit: function(response) {
                    this._settings = response.result;
                    this._unlock();
                }.bind(this)
            });

            form.on('click', '.remote_syslog_settings_save', function() {
                form.apiForm('submit');
            });

            $('#remote_syslog_settings_filter').lightCombobox(
                [
                    {label: '*.*', value: '*.*'},
                    {label: '*.=error', value: '*.=error'},
                    {label: '*.=warn', value: '*.=warn'},
                    {label: '*.=info', value: '*.=info'}
                ]
            );

            if (this._settings === null) {
                form.apiForm('load');
            }
        },

        _lock: function() {
            ap_showWaitMessage('waitDiv', 1);
        },

        _unlock: function() {
            ap_showWaitMessage('waitDiv', 0);
        }
    });

    return RemoteSyslogSettings;
}));
