(function universalModuleDefinition(root, factory) {
    if (typeof module === 'object' && module.exports) {
        // CommonJS
        module.exports = factory(require('jquery'), require('WMS'));
    } else if (typeof define === 'function' && define.amd) {
        // AMD
        define(['jquery', 'WMS'], factory);
    } else {
        // Browser
        root.ZohoCrm = factory(root.jQuery, root.WMS);
    }
}(this, function($, WMS) {
    'use strict';

    function ZohoCrm(enabled, isPbxClient, apiVersion) {
        this._enabled = enabled;
        this._isPbxClient = isPbxClient;
        this._apiVersion = apiVersion;
    }

    $.extend(ZohoCrm.prototype, {
        _content: null,

        load: function() {
            this._htmlContainer = $('#crmIntegrationsWrapper');
            window.zohoCrmIntegrationCallback = this._callback.bind(this);

            this._render();
            this._bindEvents();
        },

        enable: function() {
            ap_showWaitMessage('waitDiv', 1);

            var currentUrl = new URL(window.location.href);

            $.post('api/v1/PBX/ZohoCrm/', {location: currentUrl.protocol + '//' + currentUrl.host + '/api/Comeback/?callback=zohoCrmIntegrationCallback'})
                .done(function(response) {
                    if (response.result && typeof (response.result.accessRequest) === 'string') {
                        window.open(
                            response.result.accessRequest,
                            'Zoho CRM | Sing In', 'location=0,status=0,scrollbars=0,width=800,height=500'
                        );

                        return;
                    }

                    this._enabled = true;
                    this._render();
                }.bind(this))
                .fail(function(jqXHR) {
                    console.log(jqXHR.responseJSON.reason);
                    setError('error', WMS._t('zoho_crm.strings.failedEnable'), 5000);
                })
                .always(function() {
                    ap_showWaitMessage('waitDiv', 0);
                });
        },

        disable: function() {
            ap_showWaitMessage('waitDiv', 1);

            $.ajax('api/v1/PBX/ZohoCrm/', {method: 'DELETE', data: {'apiVersion': this._apiVersion}})
                .done(function() {
                    this._enabled = false;
                    this._render();
                }.bind(this))
                .fail(function(jqXHR) {
                    console.log(jqXHR.responseJSON.reason);
                    setError('error', jqXHR.responseJSON.reason, 5000);
                })
                .always(function() {
                    ap_showWaitMessage('waitDiv', 0);
                });
        },

        _callback: function(params) {
            var callbackErrorsMap = {
                'access_denied': WMS._t('strings.permissionsDenied'),
                'internal_error': WMS._t('phonebridge.internalError'),
                'failed_request_access_to_api': WMS._t('phonebridge.failedRequestAccessToApi'),
                'failed_switch_integration_state': WMS._t('phonebridge.failedSwitchIntegrationState'),
                'no_permission': WMS._t('phonebridge.noPermission')
            };

            if (typeof (params.error) === 'string') {
                setError('error', callbackErrorsMap[params.error], 5000);

                return;
            }

            this._confirm();
        },

        _render: function() {
            var data = {
                title: WMS._t('menu.zoho_crm_integration'),
                isAble: true,
                txt: {
                    enable: WMS._t('buttons.Enable'),
                    disable: WMS._t('buttons.Disable'),
                    disableOld: WMS._t('zoho_crm.buttons.DisableOldIntegration')
                },
                enabled: this._enabled
            };

            if (this._isPbxClient) {
                data.isAble = false;
                data.txt.notice = WMS._t('zoho_crm.strings.integrationNotAble');
            }

            var content = $.tmpl('integration_zoho_crm', data);

            if (this._content === null) {
                this._content = content;
                this._htmlContainer.append(this._content);
            } else {
                this._content.html(content.html());
            }
        },

        _bindEvents: function() {
            this._content.on('click', '#zohoCrmEnable', this.enable.bind(this));
            this._content.on('click', '#zohoCrmDisable, #zohoCrmDisableOld', this.disable.bind(this));
        },

        _confirm: function() {
            ap_showWaitMessage('waitDiv', 1);

            $.post('api/v1/PBX/ZohoCrm/confirm/')
                .done(function() {
                    this._enabled = true;
                    this._render();
                    setError('success', WMS._t('zoho_crm.strings.IntegrationIsSuccessful'), 10000);
                }.bind(this))
                .fail(function(jqXHR) {
                    console.log(jqXHR.responseJSON.reason);
                    setError('error', WMS._t('zoho_crm.strings.failedConfirm'), 5000);
                })
                .always(function() {
                    ap_showWaitMessage('waitDiv', 0);
                });
        }
    });

    return ZohoCrm;
}));
